# eric7.Project.DebuggerPropertiesFile

Module implementing a class representing the project debugger properties JSON file.

### Global Attributes

Project

### Classes

DebuggerPropertiesFile | Class representing the project debugger properties JSON file.

### Functions

None

## DebuggerPropertiesFile

Class representing the project debugger properties JSON file.

### Derived from

QObject

### Class Attributes

None

### Class Methods

None

### Methods

DebuggerPropertiesFile | Constructor
readFile | Public method to read the project debugger properties data from a project debugger properties JSON file.
writeFile | Public method to write the project debugger properties data to a project debugger properties JSON file.

### Static Methods

None

#### DebuggerPropertiesFile (Constructor)

DebuggerPropertiesFile(project: Project, parent: QObject = None)

Constructor

project (Project)
  reference to the project object
parent (QObject (optional))
  reference to the parent object (defaults to None)

#### DebuggerPropertiesFile.readFile

readFile(filename: str)

Public method to read the project debugger properties data from a project debugger properties JSON file.

filename (str)
  name of the project file

Return:
  flag indicating a successful read

Return Type:
  bool

#### DebuggerPropertiesFile.writeFile

writeFile(filename: str)

Public method to write the project debugger properties data to a project debugger properties JSON file.

filename (str)
  name of the user project file

Return:
  flag indicating a successful write

Return Type:
  bool

Up